#!/bin/bash
#set -x

CONFIG="/home/true/.config/TrueFitness/TouchApp.conf"

if [[ -f $CONFIG ]]; then
  BASETYPE=$(grep modelString $CONFIG | cut -d'=' -f2 )
fi

CONSOLE_ERROR_FILE="/data/logs/error.log"
NUCLEUS_ERROR_FILE="/data/logs/nucleus_fault.log"
DEBUG_ERROR_FILE="/data/logs/nucleusDebug.log"
OUTPUT_FILE="/data/logs/recentErrors.log"

CURR_TIME=$(date +%s)
if [[ -e $OUTPUT_FILE && -s $OUTPUT_FILE ]]; then 
  LAST_TIME=$(tail -1 $OUTPUT_FILE | cut -d, -f1)
  LAST_MILAGE=$(tail -1 $OUTPUT_FILE | cut -d, -f2)
else
  LAST_TIME=0
  LAST_MILAGE=0
fi

if [[ -s $CONSOLE_ERROR_FILE ]]; then
  nawk -F, -v baseType=$BASETYPE -v currTime=$CURR_TIME '
  BEGIN {
    errStr[0]="CN00,Corrupted Console Configuration";
    errStr[1]="CN01,Internal Error";
    errStr[2]="CN02,Invalid Console Configuration";
    errStr[3]="CN03,Stuck Key";
    errStr[4]="CN28,Console Internal Comm Fault";
    errStr[1000]="CN04,Lower Board Comm Fault";
    errStr[1001]="CN05,No Lower Control";
    errStr[1002]="CN06,Config Mismatch";
    errStr[2000]="D100,Motor Controller Fault";
    errStr[2001]="D101,Lower Board Comm Fault";
    errStr[2002]="D102,Speed Sensor Fault";
    errStr[2003]="D103,Motor Controller Fault";
    errStr[2004]="D104,Motor Controller Fault";
    errStr[2005]="D105,Insert Safety Key";
    errStr[2006]="D106,Motor Controller Fault";
    errStr[2007]="D107,Motor Over Current";
    errStr[2008]="D108,Motor Over Current";
    errStr[2009]="D109,Motor Controller Zero Current";
    errStr[2010]="D110,Motor Controller Overcurrent";
    errStr[2011]="D111,Motor Controller Voltage Overload";
    errStr[2012]="D112,Motor Controller Undervoltage";
    errStr[2013]="D113,Motor Controller Control Fault";
    errStr[2014]="D114,Lower Board Incline Range Fault";
    errStr[3000]="A101,Motor Controller Fault";
    errStr[3001]="A102,Motor Controller Fault";
    errStr[3002]="A103,Motor Controller Fault";
    errStr[3003]="A104,Motor Controller Fault";
    errStr[3004]="A105,Motor Controller Fault";
    errStr[3005]="A106,Motor Controller Fault";
    errStr[3006]="A107,Motor Controller Fault";
    errStr[3007]="A108,Motor Controller Fault";
    errStr[3008]="A109,Motor Controller Fault";
    errStr[3009]="A110,Motor Controller Fault";
    errStr[3010]="A111,Motor Controller Fault";
    errStr[3011]="A112,Motor Controller Fault";
    errStr[3012]="A113,Speed Sensor Fault";
    errStr[3013]="A114,Motor Over Temp";
    errStr[3014]="A115,Motor Over Temp";
    errStr[3015]="A117,Motor Controller Fault";
    errStr[3016]="A118,Motor Controller Fault";
    errStr[3017]="A119,Motor Controller Fault";
    errStr[3018]="A120,Motor Controller Fault";
    errStr[3019]="A121,Motor Controller Fault";
    errStr[3020]="A122,Motor Controller Fault";
    errStr[3021]="A123,Motor Controller Fault";
    errStr[3022]="A124,Motor Controller Fault";
    errStr[3023]="A125,Motor Controller Fault";
    errStr[3024]="A126,Motor Controller Fault";
    errStr[3025]="A127,Motor Controller Fault";
    errStr[3026]="A130,Motor Controller Fault";
    errStr[3027]="A131,Motor Controller Fault";
    errStr[4000]="SP01,Belt Under Speed";
    errStr[4001]="SP02,Belt Over Speed";
    errStr[4002]="SP03,Belt Over Accel";
    errStr[4003]="SP04,No Speed Signal";
    errStr[4004]="IN01,Incline Stall";
    errStr[4005]="IN02,Incline Out Of Range";
    errStr[4006]="IN03,Incline Run Fault";
    errStr[4007]="IN04,Incline Max/Min";
    errStr[4008]="CN07,Calibration Timeout";
    errStr[4009]="CN08,Calibration Failed - Lower Limit Not Reached";
    errStr[4010]="CN09,Insert Safety Key";
    errStr[4011]="SP05,Belt Over Speed";
    errStr[5000]="CN11,iPod Connection Error";
    errStr[5001]="CN12,iPod Connection Error";
    errStr[5002]="CN13,iPod Connection Error";
    errStr[5003]="CN14,iPod Connection Error";
    errStr[5004]="CN15,iPod Connection Error";
    errStr[5005]="CN16,iPod Connection Error";
    errStr[5006]="CN17,iPod Device Not Supported";
    errStr[5007]="CN18,iPod Connection Error";
    errStr[5008]="CN19,iPod Connection Error";
    errStr[5009]="CN20,iPod Connection Error";
    errStr[5010]="CN21,iPod Connection Error";
    errStr[5011]="CN22,iPod Device Not Supported";
    errStr[5012]="CN23,iPod Device Not Supported";
    errStr[6000]="CN24,Console Internal Comm Fault";
    errStr[6001]="CN25,Firmware Mismatch";
    errStr[6002]="CN26,Console Internal Comm Fault";
    errStr[6003]="CN27,Console Internal Comm Fault";
    errStr[6004]="CN29,Console Internal Comm Fault";
    errStr[7000]="SC00,Lower Board Comm Fault";
    errStr[7001]="SC01,Lower Board Comm Fault";
    errStr[7002]="SC02,Incline Stall";
    errStr[7003]="SC03,Incline Run Fault";
    errStr[7004]="SC04,Motor Under Speed";
    errStr[7005]="SC05,Motor Over Speed";
    errStr[7006]="SC06,Motor Acceleration Fault";
    errStr[7007]="SC07,Speed Sensor Fault";
    errStr[7008]="CN10,E-Stop Fault";
    errStr[7009]="SC08,Smartcard Checksum Error";
    errStr[7010]="CN30,Control Board Fault";
    errStr[8000]="X101,Stride Adjust Stall";
    errStr[8001]="X102,Stride Adjust Runaway";
    errStr[9000]="CN36,USB Connection Terminated";
  }{
    date=$1; milage=$2/100;
    gsub(/[ \t\r\n]+$/, "", $3); errnum=$3; 
    if (errnum in errStr) 
      msg=errStr[errnum];
    else
      msg="Unknown Error";
    cmd=sprintf("date -d \"%s\" +%%s", date);
    cmd | getline dateSec;
    print dateSec","milage","date","baseType","msg;
  }' $CONSOLE_ERROR_FILE > $OUTPUT_FILE.tmp
fi

if [[ -s $NUCLEUS_ERROR_FILE ]]; then
  nawk -F, '{
    date=$1; milage=$2;
    if (date~/Time/) {
      print "0,"milage","$0
    }
    else {
      cmd=sprintf("date -d \"%s\" +%%s", date);
      cmd | getline dateSec;
      print dateSec","milage","$0;
    }
  }' $NUCLEUS_ERROR_FILE >> $OUTPUT_FILE.tmp
fi

if [[ -s $DEBUG_ERROR_FILE ]]; then
  nawk -F, '{
    print $2$0;
  }' $DEBUG_ERROR_FILE > $DEBUG_ERROR_FILE.tmp

  nawk -F'|' '{
    milage=$1/100;
    dateSec=$3;
    printf "%d", dateSec/1000;
    print ","milage","$2","$4;
  }' $DEBUG_ERROR_FILE.tmp >> $OUTPUT_FILE.tmp

  rm $DEBUG_ERROR_FILE.tmp
fi

# Remove entries before last checked epic time
if [[ -s $OUTPUT_FILE.tmp ]]; then
  nawk -F, -v lastTime=$LAST_TIME -v lastMilage=$LAST_MILAGE '{
    epic=$1; 
    milage=$2;
    if(epic > lastTime) {
      print $0;
    } else if (epic == 0 && milage >= lastMilage) {
      print $0;
    }
  }' $OUTPUT_FILE.tmp > $OUTPUT_FILE.tmp2

  rm $OUTPUT_FILE.tmp
fi

if [[ -s "$OUTPUT_FILE.tmp2" ]]; then
  # Sort error file
  sort -t, -n -k 2 $OUTPUT_FILE.tmp2 > $OUTPUT_FILE

  CURR_MILAGE=$(tail -1 $OUTPUT_FILE | cut -d, -f2)
  rm $OUTPUT_FILE.tmp2
  echo "$CURR_TIME,$CURR_MILAGE, Last check time" >> $OUTPUT_FILE
else
  CURR_MILAGE=$LAST_MILAGE
  echo "$CURR_TIME,$CURR_MILAGE, Last check time" > $OUTPUT_FILE
fi

cat $OUTPUT_FILE

