#!/bin/bash

# Define help function
function help(){
  echo "syncAssets - Sync assets of the Primary to the Replicas";
  echo "Usage example:";
  echo "syncassets [(-h|--help)] [(-s|--screensavers)] [(-f|--facility)] [(-t|--timers)] [(-u|--update)] [(-T|--tv)] [(-b|--banner)]";
  echo "Options:";
  echo "-h or --help: Displays this information.";
  echo "-s or --screensavers: Syncs the screensaver images.";
  echo "-f or --facility: Syncs the facility images.";
  echo "-t or --timers: Syncs the timer settings.";
  echo "-u or --update: Triggers software update on all replicas.";
  echo "-T or --TV: Syncs tv_conf.xml file.";
  echo "-b or --banner: Syncs the custom 'attract video'.";

  exit 1;
}

# Declare vars. Flags initalizing to 0.
screensavers=0;
facility=0;
timers=0;
update=0;
tv=0;

# Execute getopt
ARGS=$(getopt -o "hsftuTb" -l "help,screensavers,facility,timers,update,tv,banner" -n "syncAssets" -- "$@");

#Bad arguments
if [ $? -ne 0 ];
then
  help;
fi
SCRIPT=$(basename "${BASH_SOURCE[0]}")
echo "Running $SCRIPT"

eval set -- "$ARGS";

# now enjoy the options in order and nicely split until we see --
while true; do
  case "$1" in
    -h|--help)
    shift;
    help;
    ;;
    -s|--screensavers)
    shift;
    screensavers="1";
    ;;
    -f|--facility)
    shift;
    facility="1";
    ;;
    -t|--timers)
    shift;
    timers="1";
    ;;
    -u|--update)
    shift;
    update="1";
    ;;
    -T|--tv)
    shift;
    tv="1";
    ;;
    -b|--banner)
    shift;
    banner="1";
    ;;
    --)
    shift;
    break;
    ;;
  esac
done

echo "screensavers: $screensavers, facility-images: $facility, timers: $timers, update-software: $update, TV: $tv, Banner: $banner"


if [ "$screensavers" = "1" ]; then
  echo "syncing screensaver files"

  IMG_DIR=/data/slideshow/user
  SALT_IMG_DIR=/srv/salt/managed-files"$IMG_DIR"

  if [[ -d $SALT_IMG_DIR ]]; then
    sudo rm -f "$SALT_IMG_DIR"/*
  else
    sudo mkdir -p $SALT_IMG_DIR
  fi

  if  find $IMG_DIR -mindepth 1 | read ; then
    sudo cp  "$IMG_DIR"/* "$SALT_IMG_DIR"
  fi

  sudo salt '*' state.sls console.syncSlideshow --state-output=mixed
  echo "done"

fi

if [ "$facility" = "1" ]; then

  echo "syncing facility-images"
  IMG_DIR=/data/facility/user
  SALT_IMG_DIR=/srv/salt/managed-files"$IMG_DIR"

  if [[ -d $SALT_IMG_DIR ]]; then
    sudo rm -f "$SALT_IMG_DIR"/*
  else
    sudo mkdir -p $SALT_IMG_DIR
  fi

  if  find $IMG_DIR -mindepth 1 | read ; then
    sudo cp  "$IMG_DIR"/* "$SALT_IMG_DIR"
  fi

  sudo salt '*' state.sls console.syncFacilityImages --state-output=mixed
  echo "done"
fi

if [ "$timers" = "1" ]; then

  echo "syncing TV configuration"
  SRC=/home/true/.config/TrueFitness/TouchApp.conf
  DEST=/srv/salt/managed-files/timers

  if [ -f $DEST ]; then
    sudo rm $DEST
    sudo touch $DEST
  fi

  echo "#-- The following entries were managed by Saltstack" | sudo tee -a $DEST

  # Cooldown Time
  grep "cooldownTime" $SRC  | sudo tee -a $DEST

  # Maximum Workout Time
  grep "workoutTimeMax" $SRC | sudo tee -a $DEST

  # Workout Setup Timeout
  grep "workoutSetupTimeout" $SRC | sudo tee -a $DEST

  # Maximum Workout Time
  grep "workoutSummaryTimeout" $SRC |sudo tee -a $DEST

  # Cooldown Time
  grep "resumeWorkoutTimeout" $SRC |sudo tee -a $DEST

  sudo salt '*' state.sls console.syncTimers
  echo "done"
fi

if [ "$update" = "1" ]; then
  echo "Updating Software"
  sudo salt '*' state.sls console.softwareUpdate
  /srv/scripts/makePrimary.sh
  echo "done"
fi

if [ "$tv" = "1" ]; then
  TV_DIR=/data
  TV_CONF=tv_conf.xml
  SALT_TV_DIR=/srv/salt/managed-files$TV_DIR

  if [[ -d $SALT_TV_DIR ]]; then
    if [[ -f $SALT_TV_DIR/$TV_CONF ]]; then
      sudo rm -f "$SALT_TV_DIR"/$TV_CONF
    fi
  else
    sudo mkdir -p $SALT_TV_DIR
  fi
  sudo cp  "$TV_DIR/$TV_CONF" "$SALT_TV_DIR"

  echo "syncing files"
  sudo salt '*' state.sls console.syncTVconf --state-output=mixed
  echo "done"
fi

if [ "$banner" = "1" ]; then

  echo "syncing banner (attract) video"
  VID_DIR=/data/video/attract/user
  SALT_VID_DIR=/srv/salt/managed-files"$VID_DIR"

  if [[ -d $SALT_VID_DIR ]]; then
    sudo rm -f "$SALT_VID_DIR"/*
  else
    sudo mkdir -p $SALT_VID_DIR
  fi

  if  find "$VID_DIR" -mindepth 1 | read ; then
    sudo cp  "$VID_DIR"/* "$SALT_VID_DIR"
  fi
  sudo salt '*' state.sls console.syncAttractVideo --state-output=mixed
  echo "done"

fi



#reset all of the minions except for the local one
sudo salt -G 'roles:salt-minion' --async  cmd.run '/srv/scripts/reset_minion.sh'

sudo rm $LIST
# /srv/scripts/reset_master.sh
/srv/scripts/makeMinion.sh
